@@ -10,9 +10,6 @@
 #' @param part partname of the table (one of 'body', 'header', 'footer')
 #' @seealso [as_chunk()], [as_sup()], [as_sub()], [colorize()]
 #' @family functions for mixed content paragraphs
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_append_chunks_1.png}{options: width="100"}}
 #' @examples
 #' library(flextable)
 #' img.file <- file.path(R.home("doc"), "html", "logo.jpg")
@@ -30,8 +27,9 @@
 #' ft_1 <- set_table_properties(ft_1, layout = "autofit")
 #' ft_1
 append_chunks <- function (x, ..., i = NULL, j = NULL, part = "body"){
-  if (!inherits(x, "flextable"))
-    stop("append_chunks supports only flextable objects.")
+  if (!inherits(x, "flextable")){
+    stop(sprintf("Function `%s` supports only flextable objects.", "append_chunks()"))
+  }
   part <- match.arg(part, c("body", "header", "footer"),
                     several.ok = FALSE)
 
@@ -83,12 +81,14 @@ append_chunks <- function (x, ..., i = NULL, j = NULL, part = "body"){
 #' x <- prepend_chunks(
 #'   x,
 #'   i = 1, j = 1,
-#'   colorize(as_b("coucou "), color = "red")
+#'   colorize(as_b("Hello "), color = "red"),
+#'   colorize(as_i("World"), color = "magenta")
 #' )
 #' x
 prepend_chunks <- function (x, ..., i = NULL, j = NULL, part = "body"){
-  if (!inherits(x, "flextable"))
-    stop("append_chunks supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "prepend_chunks()"))
+  }
   part <- match.arg(part, c("body", "header", "footer"),
                     several.ok = FALSE)
 
@@ -103,8 +103,8 @@ prepend_chunks <- function (x, ..., i = NULL, j = NULL, part = "body"){
 
   tmp_data <- x[[part]]$dataset[i, , drop = FALSE]
 
-  for(col_expr in col_exprs){
-
+  for(expr_index in rev(seq_along(col_exprs))){
+    col_expr <- col_exprs[[expr_index]]
     value <- eval_tidy(col_expr, data = tmp_data)
 
     if(is.data.frame(value) && nrow(value) == 1L && nrow(value) < nrow(tmp_data)){
@@ -115,15 +115,14 @@ prepend_chunks <- function (x, ..., i = NULL, j = NULL, part = "body"){
     if(is.data.frame(value))
       value <- split(value, i)
 
-    new <- mapply(function(x, y) {
-      y$seq_index <- min(x$seq_index, na.rm = TRUE) - 1
+    new <- mapply(function(x, y, seq_index) {
+      y$seq_index <- seq_index
       z <- rbind.match.columns(list(y, x))
-      z$seq_index <- seq_len(nrow(z))
+      z <- z[order(z$seq_index),]
+      z$seq_index <- rleid(z$seq_index)
       z
-    }, x = x[[part]]$content[i, j], y = value, SIMPLIFY = FALSE)
-
+    }, x = x[[part]]$content[i, j], y = value, SIMPLIFY = FALSE, MoreArgs = list(seq_index=-expr_index))
     x[[part]]$content[i, j] <- new
   }
-
   x
 }
