@@ -208,9 +208,6 @@ wml_rows <- function(value, split = FALSE) {
 
   # get runs in wml format and get hyperlinks and images information
   run_data <- runs_as_wml(value, txt_data = fortify_run(value))
-  hlinks <- attr(run_data, "hlinks")
-  imgs <- attr(run_data, "imgs")
-
 
   cell_data <- wml_cells(value, cell_attributes)
   cell_heights <- fortify_height(value)
@@ -271,22 +268,15 @@ wml_rows <- function(value, split = FALSE) {
     "</w:trPr>", wml, "</w:tr>"
   )
 
-  rows <- paste0(rows, collapse = "")
-
-  attr(rows, "imgs") <- imgs
-  attr(rows, "hlinks") <- hlinks
-
-  rows
+  paste0(rows, collapse = "")
 }
 
 
 # docx_str -----
-gen_raw_wml <- function(x,
-                        align = "center",
-                        split = FALSE,
-                        keep_with_next = TRUE,
-                        doc = NULL,
-                        ...) {
+gen_raw_wml <- function(x, doc = NULL, ...) {
+
+  align <- x$properties$align
+
   align <- match.arg(align, c("center", "left", "right"), several.ok = FALSE)
   align <- c("center" = "center", "left" = "start", "right" = "end")[align]
   align <- as.character(align)
@@ -294,7 +284,8 @@ gen_raw_wml <- function(x,
   dims <- dim(x)
   widths <- dims$widths
 
-  x <- keep_wn(x, part = "all", keep_with_next = keep_with_next)
+  x <- keep_wn(x, part = "all",
+               keep_with_next = x$properties$opts_word$keep_with_next)
 
   out <- paste0(
     "<w:tbl xmlns:w=\"http://schemas.openxmlformats.org/wordprocessingml/2006/main\" ",
@@ -334,31 +325,8 @@ gen_raw_wml <- function(x,
 
   out <- paste0(out, properties_str)
 
-  tab_str <- wml_rows(x, split = split)
+  tab_str <- wml_rows(x, split = x$properties$opts_word$split)
   out <- paste0(out, tab_str, "</w:tbl>")
 
-  imgs <- unique(attr(tab_str, "imgs"))
-  hlinks <- attr(tab_str, "hlinks")
-
-  if (length(imgs) > 0) {
-    if (!is.null(doc)) {
-      stopifnot(inherits(doc, "rdocx"))
-      doc <- docx_reference_img(doc, imgs)
-      out <- wml_link_images(doc, out)
-    }
-  }
-  if (length(hlinks) > 0) {
-    if (!is.null(doc)) {
-      stopifnot(inherits(doc, "rdocx"))
-      rel <- doc$doc_obj$relationship()
-      out <- process_url(
-        relation_object = rel,
-        urls_set = hlinks,
-        ooxml_str = out,
-        pattern = "w:hyperlink"
-      )
-    }
-  }
-
   out
 }
