@@ -38,6 +38,19 @@ htmltools_value <- function(x, ft.align = NULL, ft.shadow = NULL) {
   html_o
 }
 
+#' @export
+as.character.flextable <- function(x, ...) {
+  x <- flextable_global$defaults$post_process_html(x)
+  x$properties$opts_html$shadow <- FALSE
+  caption <- caption_default_html(x, align = x$properties$align)
+  manual_css <- attr(caption, "css")
+  gen_raw_html(x,
+               class = "tabwid",
+               caption = caption,
+               manual_css = manual_css
+  )
+}
+
 #' @export
 #' @title flextable raw code
 #'
@@ -372,6 +385,7 @@ knit_to_wml <- function(x, bookdown = FALSE, quarto = FALSE) {
 #' @examples
 #' knit_to_latex(flextable(airquality[1:5, ]))
 #' @importFrom officer opts_current_table run_autonum to_wml
+#' @importFrom knitr raw_block
 knit_to_latex <- function(x, bookdown, quarto = FALSE) {
 
   align <- x$properties$align
@@ -431,6 +445,19 @@ knit_to_latex <- function(x, bookdown, quarto = FALSE) {
     container_str[2],
     sep = "\n\n"
   )
+  z <- paste(
+    "\\global\\setlength{\\Oldarrayrulewidth}{\\arrayrulewidth}",
+    "\\global\\setlength{\\Oldtabcolsep}{\\tabcolsep}",
+    sprintf("\\setlength{\\tabcolsep}{%spt}", format_double(x$properties$opts_pdf$tabcolsep, 0)),
+    sprintf("\\renewcommand*{\\arraystretch}{%s}", format_double(x$properties$opts_pdf$arraystretch, 2)),
+    latex,
+    sprintf("\\arrayrulecolor[HTML]{%s}", colcode0(x$properties$opts_pdf$default_line_color)),
+    "\\global\\setlength{\\arrayrulewidth}{\\Oldarrayrulewidth}",
+    "\\global\\setlength{\\tabcolsep}{\\Oldtabcolsep}",
+    "\\renewcommand*{\\arraystretch}{1}",
+    sep = "\n\n"
+  )
+  raw_block(z, type = "latex")
 }
 
 knit_to_pml <- function(x, left = opts_current$get("ft.left"),
@@ -481,7 +508,9 @@ knit_to_pml <- function(x, left = opts_current$get("ft.left"),
 #' @importFrom rmarkdown render pdf_document
 #' @importFrom officer read_pptx add_slide read_docx
 print.flextable <- function(x, preview = "html", align = "center", ...) {
-  if (!interactive() || "log" %in% preview) {
+  if (is_in_pkgdown()) {
+    return(htmltools_value(x, ft.shadow = TRUE, ft.align = align))
+  } else if (!interactive() || "log" %in% preview) {
     cat("a flextable object.\n")
     cat("col_keys:", paste0("`", x$col_keys, "`", collapse = ", "), "\n")
     cat("header has", nrow(x$header$dataset), "row(s)", "\n")
@@ -512,6 +541,11 @@ print.flextable <- function(x, preview = "html", align = "center", ...) {
   invisible(NULL)
 }
 
+is_in_pkgdown <- function() {
+  identical(Sys.getenv("IN_PKGDOWN"), "true") &&
+  requireNamespace("pkgdown", quietly = TRUE)
+}
+
 #' @title Render flextable in rmarkdown
 #' @description Function used to render flextable in knitr/rmarkdown documents.
 #'
@@ -984,8 +1018,9 @@ save_as_docx <- function(..., values = NULL, path, pr_section = NULL, align = "c
 #' @family flextable print function
 save_as_image <- function(x, path, zoom = 3, expand = 10, webshot = "webshot") {
   if (!inherits(x, "flextable")) {
-    stop("x must be a flextable")
+    stop(sprintf("Function `%s` supports only flextable objects.", as.character(sys.call()[[1]])))
   }
+
   if (!requireNamespace(webshot, quietly = TRUE)) {
     stop(sprintf(
       "'%s' package should be installed to create an image from a flextable.",
