@@ -26,12 +26,12 @@
 #' )
 #'
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_style_1.png}{options: width="500"}}
 style <- function(x, i = NULL, j = NULL,
                   pr_t = NULL, pr_p = NULL, pr_c = NULL, part = "body") {
-  if (!inherits(x, "flextable")) stop("style supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "style()"))
+  }
+
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -87,11 +87,11 @@ style <- function(x, i = NULL, j = NULL,
 #' @examples
 #' ft <- flextable(head(iris))
 #' ft <- bold(ft, bold = TRUE, part = "header")
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_bold_1.png}{options: width="400"}}
 bold <- function(x, i = NULL, j = NULL, bold = TRUE, part = "body") {
-  if (!inherits(x, "flextable")) stop("bold supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "bold()"))
+  }
+
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -133,11 +133,10 @@ bold <- function(x, i = NULL, j = NULL, bold = TRUE, part = "body") {
 #' ft <- fontsize(ft, size = 14, j = 2)
 #' ft <- fontsize(ft, size = 7, j = 3)
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_fontsize_1.png}{options: width="400"}}
 fontsize <- function(x, i = NULL, j = NULL, size = 11, part = "body") {
-  if (!inherits(x, "flextable")) stop("fontsize supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "fontsize()"))
+  }
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -171,11 +170,11 @@ fontsize <- function(x, i = NULL, j = NULL, size = 11, part = "body") {
 #' @examples
 #' ft <- flextable(head(mtcars))
 #' ft <- italic(ft, italic = TRUE, part = "header")
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_italic_1.png}{options: width="400"}}
 italic <- function(x, i = NULL, j = NULL, italic = TRUE, part = "body") {
-  if (!inherits(x, "flextable")) stop("italic supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "italic()"))
+  }
+
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -237,11 +236,11 @@ italic <- function(x, i = NULL, j = NULL, italic = TRUE, part = "body") {
 #' ft <- highlight(ft, j = "disp", i = ~ disp > 200, color = "yellow")
 #' ft <- highlight(ft, j = ~ drat + wt + qsec, color = my_color_fun)
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_highlight_1.png}{options: width="500"}}
 highlight <- function(x, i = NULL, j = NULL, color = "yellow", part = "body", source = j) {
-  if (!inherits(x, "flextable")) stop("highlight supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "highlight()"))
+  }
+
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -324,13 +323,11 @@ highlight <- function(x, i = NULL, j = NULL, color = "yellow", part = "body", so
 #'   ft_2 <- set_formatter_type(ft_2)
 #'   ft_2
 #' }
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_color_1.png}{options: width="600"}}
-#'
-#' \if{html}{\figure{fig_color_2.png}{options: width="400"}}
 color <- function(x, i = NULL, j = NULL, color, part = "body", source = j) {
-  if (!inherits(x, "flextable")) stop("color supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "color()"))
+  }
+
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -400,13 +397,11 @@ color <- function(x, i = NULL, j = NULL, color, part = "body", source = j) {
 #'   ft_2 <- font(ft_2, fontname = fontname, j = 5)
 #'   ft_2
 #' }
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_font_1.png}{options: width="500"}}
-#'
-#' \if{html}{\figure{fig_font_2.png}{options: width="500"}}
 font <- function(x, i = NULL, j = NULL, fontname, part = "body", cs.family = fontname, hansi.family = fontname, eastasia.family = fontname) {
-  if (!inherits(x, "flextable")) stop("font supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "font()"))
+  }
+
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -469,14 +464,14 @@ font <- function(x, i = NULL, j = NULL, fontname, part = "body", cs.family = fon
 #' ft_1 <- padding(ft_1, padding.bottom = 10, part = "header")
 #' ft_1 <- autofit(ft_1)
 #' ft_1
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_padding_1.png}{options: width="400"}}
 padding <- function(x, i = NULL, j = NULL, padding = NULL,
                     padding.top = NULL, padding.bottom = NULL,
                     padding.left = NULL, padding.right = NULL,
                     part = "body") {
-  if (!inherits(x, "flextable")) stop("padding supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "padding()"))
+  }
+
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (!is.null(padding)) {
@@ -538,12 +533,11 @@ padding <- function(x, i = NULL, j = NULL, padding = NULL,
 #' ft <- align(ft, align = "right", part = "all")
 #' ft <- theme_tron_legacy(ft)
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_align_1.png}{options: width="400"}}
 align <- function(x, i = NULL, j = NULL, align = c("left", "center", "right", "justify"),
                   part = "body") {
-  if (!inherits(x, "flextable")) stop("align supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "align()"))
+  }
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
   align_value <- match.arg(align)
 
@@ -601,18 +595,13 @@ keep_wn <- function(x, i = NULL, j = NULL, keep_with_next = TRUE,
 #' @param j columns selection
 #' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
 #' @param space space between lines of text, 1 is single line spacing, 2 is double line spacing.
-#' @param unit unit for space, one of "in", "cm", "mm".
 #' @family sugar functions for table style
 #' @examples
 #' ft <- flextable(head(mtcars)[, 3:6])
 #' ft <- line_spacing(ft, space = 1.6, part = "all")
 #' ft <- set_table_properties(ft, layout = "autofit")
 #' ft
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_line_spacing_1.png}{options: width="400"}}
-line_spacing <- function(x, i = NULL, j = NULL, space = 1, part = "body", unit = "in") {
-  space <- convin(unit = unit, x = space)
+line_spacing <- function(x, i = NULL, j = NULL, space = 1, part = "body") {
 
   if (!inherits(x, "flextable")) stop("align supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
@@ -721,13 +710,10 @@ align_nottext_col <- function(x, align = "right", header = TRUE, footer = TRUE)
 #'   )
 #'   ft_2
 #' }
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_bg_1.png}{options: width="400"}}
-#'
-#' \if{html}{\figure{fig_bg_2.png}{options: width="300"}}
 bg <- function(x, i = NULL, j = NULL, bg, part = "body", source = j) {
-  if (!inherits(x, "flextable")) stop("bg supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "bg()"))
+  }
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -802,13 +788,10 @@ data_colors <- function(dataset, fun) {
 #'
 #' ft_2 <- valign(ft_1, j = 5, valign = "top", part = "all")
 #' ft_2
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_valign_1.png}{options: width="400"}}
-#'
-#' \if{html}{\figure{fig_valign_2.png}{options: width="400"}}
 valign <- function(x, i = NULL, j = NULL, valign = "center", part = "body") {
-  if (!inherits(x, "flextable")) stop("valign supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "valign()"))
+  }
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -904,11 +887,10 @@ valign <- function(x, i = NULL, j = NULL, valign = "center", part = "body") {
 #' ft_2 <- valign(ft_2, i = 3, valign = "bottom")
 #'
 #' ft_2
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_rotate_1.png}{options: width="400"}}
 rotate <- function(x, i = NULL, j = NULL, rotation, align = NULL, part = "body") {
-  if (!inherits(x, "flextable")) stop("rotate supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "rotate()"))
+  }
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE)
 
   if (part == "all") {
@@ -974,7 +956,9 @@ rotate <- function(x, i = NULL, j = NULL, rotation, align = NULL, part = "body")
 #' @export
 #' @importFrom officer shortcuts
 empty_blanks <- function(x, width = .05, unit = "in", part = "all") {
-  if (!inherits(x, "flextable")) stop("empty_blanks supports only flextable objects.")
+  if (!inherits(x, "flextable")) {
+    stop(sprintf("Function `%s` supports only flextable objects.", "empty_blanks()"))
+  }
   if (length(x$blanks) < 1) {
     return(x)
   }
