@@ -4,8 +4,6 @@
 #' @description Get a `flextable` object from
 #' a `xtable` object.
 #'
-#' `xtable_to_flextable` will be deprecated in favor of `as_flextable.xtable`.
-#'
 #' @param x `xtable` object
 #' @param text.properties default text formatting properties
 #' @param format.args List of arguments for the formatC function.
@@ -57,13 +55,6 @@
 #'   detach("package:xtable", unload = TRUE)
 #' }
 #' @export
-#' @section Illustrations:
-#'
-#' \if{html}{\figure{fig_as_flextable.xtable_1.png}{options: width="300"}}
-#'
-#' \if{html}{\figure{fig_as_flextable.xtable_2.png}{options: width="300"}}
-#'
-#' \if{html}{\figure{fig_as_flextable.xtable_3.png}{options: width="500"}}
 #' @family as_flextable methods
 as_flextable.xtable <- function(
   x, text.properties = fp_text_default(),
@@ -253,9 +244,6 @@ as_flextable.xtable <- function(
   ft
 }
 
-#' @export
-#' @rdname as_flextable.xtable
-xtable_to_flextable <- as_flextable.xtable
 
 get_xtable_widths <- function(align, default_width = .3){
   rex <- "^(p\\{)([0-9\\.]+)(cm|in|px)(\\}$)"
